Installation and running — BCI-Framework documentation

# Installation and running

BCI-Framework needs Python >= 3.8 due the utilizations of cached_property and the amazing new walrus operator, priors versions were not tested and there is not planning to do it.

## Install from PyPi

    [ ]:

    $ pip install -U bci-framework
    $ bci-framework

## Install from source code

    [ ]:

    $ git clone https://github.com/UN-GCPDS/bci-framework.git
    $ cd bci-framework
    $ pip install -r requirements.txt
    $ python setup.py install
    $ python -m bci_framework

## Install in virtual environment

    [ ]:

    $ python -m venv bciframework-env
    $ source bciframework-env/bin/activate
    $ pip install -U bci-framework
    $ python -m bci_framework

## Running

With the hardware properly configured we can start the BCI-Framework application.
If you are running from source code, you must start the application as a named module:

    [ ]:

    $ python -m bci_framework

If the application is already installed, then the `bci-framework` command is available to run from the terminal:

    [ ]:

    $ bci-framework